#include <sdcc-lib.h>
#include <pic16f648a.h>	// /usr/share/sdcc/non-free/include/pic14/pic16f648a.h, /usr/share/sdcc/include/pic14/pic16f648a.h
#include "inline.h"
#include "libwait.h"
#include "libusart.h"

__code unsigned char __at 0x2000 id_location[] = {'A', 'B', 'C', 'D'};

unsigned int __at 0x2007 __config =
	_CP_OFF &
	_DATA_CP_OFF &
	_LVP_OFF &
	_BOREN_OFF &	// for 4.0V
	_MCLRE_OFF &
	_PWRTE_OFF &
	_WDT_OFF &
	_INTOSC_OSC_NOCLKOUT;

__code unsigned char __at 0x2100 eedata[] = {'d', 'u', 'm', 'm', 'y', 0};

#define	LED1	RA0

void Intr(void) __interrupt 0 {
	T0IF = 0;						// Clear timer interrupt
}

/*			  _______
	NC		-|2	 U	1|-	NC
	NC		-|3		0|-	LED1
	NC		-|4	 A	7|-	NC
	NC		-|5		6|-	NC
	GND		-|		 |-	Vcc
	NC		-|0		7|-	NC
	RX		-|1		6|-	NC
	TX		-|2	 B	5|-	NC
	NC		-|3_____4|-	NC
*/

void main(void) {
				//  76543210
	PORTA		= 0b00000000;		// RA4: open drain, RA5: input only
	CMCON		= 0b00000111;
	TRISA		= 0b00100000;		// 1: 入力, 0: 出力

	PORTB		= 0b00000000;
	TRISB		= 0b00000110;		// 1: 入力, 0: 出力

	OPTION_REG	= 0b11111111;		// 初期値:0b11111111
									// 7:PORTBプルアップ(0:使用する)
									// 6:RB0割り込みポート変化選択(0:立下り)
									// 5:TMR0クロックソース選択ビット(0:内部)
									// 4:TMR0加算タイミング(0:立上り)
									// 3:プリスケーラ割り当てビット(0:TMR0)
									// 2~0プリスケーラレート選択ビット(011:1/16)
									// 4MHz => 1MHz = 1,000,000 / 16 / 256 = 244Hz

	INTCON		= 0b00000000;		// 初期値:0b0000000x
									// 7:GIE  Global Interrupt Enable bit
									// 6:PEIE Peripheral Interrupt Enable bit
									// 5:T0IE TMR0 Overflow Interrupt Enable bit
									// 4:INTE RB0/INT External Interrupt Enable bit
									// 3:RBIE RB Port Change Interrupt Enable bit
									// 2:T0IF TMR0 Overflow Interrupt Flag bit
									// 1:INTF RB0/INT External Interrupt Flag bit
									// 0:RBIF RB Port Change Interrupt Flag bit

	PIR1		= 0b00000000;		// 初期値:0b00000000(フラグ)
	PIE1		= 0b00000000;		// 初期値:0b00000000(イネーブル)
									// 7:EEIE EE Write Complete Interrupt Enable Bit
									// 6:CMIE Comparator Interrupt Enable bit
									// 5:RCIE USART Receive Interrupt Enable bit
									// 4:TXIE USART Transmit Interrupt Enable bit
									// 2:CCP1IE CCP1 Interrupt Enable bit
									// 1:TMR2IE TMR2 to PR2 Match Interrupt Enable bit
									// 0:TMR1IE TMR1 Overflow Interrupt Enable bit

	T1CON		= 0b00000000;		// 初期値:0b00000000
									// 5~4:T1CKPS Timer1 Input Clock Prescale Select bits(00:1/1, 11:1/8)
									// 3:T1OSCEN Timer1 Oscillator Enable Control bit(1:Enable)
									// 2:T1SYNC Timer1 External Clock Input Synchronization Control bit(1:Sync)
									// 1:TMR1CS Timer1 Clock Source Select bit(0:Internal)
									// 0:TMR1ON Timer1 On bit(1:Enable)

	T2CON		= 0b00000000;		// 初期値:0b00000000
									// 6~3:TOUTPS Timer2 Output Postscale Select bits(0000:1/1, 0011:1/4, 1111:1/16)
									// 2:TMR2ON Timer2 On bit(1:ON)
									// 1~0:T2CKPS Timer2 Clock Prescale Select bits(00:1/1, 01:1/4, 1x:1/16)

//	forCalibOsc();
	initUsart();

	//--------------------------------------------------------------------------
	//
	//	Main Loop
	//
	while(1) {
		LED1 = 1;
		transmitUsart(0x55);
		waitL(5);

		LED1 = 0;
		transmitUsart(0xAA);
		waitL(10);
	}
}

